@@ -1,6 +1,6 @@
 /* GCompris - balancebox.js
  *
- * Copyright (C) 2014-2015 Holger Kaelberer <holger.k@elberer.de>
+ * Copyright (C) 2014-2016 Holger Kaelberer <holger.k@elberer.de>
  *
  * Authors:
  *   Holger Kaelberer <holger.k@elberer.de>
@@ -81,6 +81,7 @@ var goalComponent = Qt.createComponent("qrc:/gcompris/src/activities/balancebox/
 var contactIndex = -1;
 var pendingObjects = 0;
 var pendingReconfigure = false;
+var finishRunning = false;
 
 function start(items_) {
     items = items_;
@@ -106,9 +107,15 @@ function start(items_) {
                 items.tilt.invertX = true;
             }
         }
-        var levelsFile = builtinFile;
+        var levelsFile;
         if (items.levelSet === "user")
             levelsFile = userFile;
+        else {
+            levelsFile = builtinFile;
+            currentLevel = GCompris.ApplicationSettings.loadActivityProgress(
+                        "balancebox");
+        }
+
         dataset = items.parser.parseFromUrl(levelsFile, validateLevels);
         if (dataset == null) {
             console.error("Balancebox: Error loading levels from " + levelsFile
@@ -207,15 +214,20 @@ function checkBallContacts()
 
 function finishBall(won, x, y)
 {
+    finishRunning = true;
     items.timer.stop();
     items.keyboardTimer.stop();
     items.ball.x = x;
     items.ball.y = y;
     items.ball.scale = 0.4;
     items.ball.body.linearVelocity = Qt.point(0, 0);
-    if (won)
+    if (won) {
         items.bonus.good("flower");
-    else
+        if (items.levelSet === "builtin" && items.mode === "play") {
+            GCompris.ApplicationSettings.saveActivityProgress("balancebox",
+                        currentLevel+1 >= numberOfLevel ? 0 : currentLevel+1);
+        }
+    } else
         items.bonus.bad("flower");
 }
 
@@ -281,6 +293,7 @@ function initMap()
     var modelMap = new Array();
     incubators = new Array();
     goalUnlocked = true;
+    finishRunning = false;
     items.mapWrapper.rows = map.length;
     items.mapWrapper.columns = map[0].length;
     pendingObjects = 0;
