@@ -27,9 +27,8 @@
 #include <config.h>
 #include "ApplicationSettings.h"
 
-#include <qqml.h>
-#include <QtCore/QObject>
-#include <QtQml/QQmlPropertyMap>
+#include <QObject>
+#include <QQmlPropertyMap>
 #include <QQmlEngine>
 #include <QtGlobal>
 
