@@ -22,17 +22,19 @@
 #include "ApplicationSettings.h"
 #include "ApplicationInfo.h"
 
-#include <QtCore/qmath.h>
-#include <QtCore/QUrl>
-#include <QtCore/QUrlQuery>
-#include <QtGui/QGuiApplication>
-#include <QtGui/QScreen>
-#include <QtCore/QLocale>
+#include <qmath.h>
+#include <QUrl>
+#include <QUrlQuery>
+#include <QGuiApplication>
+#include <QScreen>
+#include <QLocale>
 
 #include <QSettings>
 #include <QStandardPaths>
 #include <QDebug>
 
+#include <QtQml>
+
 #define GC_DEFAULT_FONT "Andika-R.ttf"
 #define GC_DEFAULT_FONT_CAPITALIZATION 0 // Font.MixedCase
 
@@ -67,6 +69,8 @@ static const QString DEMO_KEY = "demo";
 static const QString KIOSK_KEY = "kiosk";
 static const QString SECTION_VISIBLE = "sectionVisible";
 
+static const QString PROGRESS_KEY = "progress";
+
 ApplicationSettings *ApplicationSettings::m_instance = NULL;
 
 ApplicationSettings::ApplicationSettings(QObject *parent): QObject(parent),
@@ -129,22 +133,22 @@ ApplicationSettings::ApplicationSettings(QObject *parent): QObject(parent),
     // no group
     m_isBarHidden = false;
 
-    connect(this, SIGNAL(showLockedActivitiesChanged()), this, SLOT(notifyShowLockedActivitiesChanged()));
-	connect(this, SIGNAL(audioVoicesEnabledChanged()), this, SLOT(notifyAudioVoicesEnabledChanged()));
-	connect(this, SIGNAL(audioEffectsEnabledChanged()), this, SLOT(notifyAudioEffectsEnabledChanged()));
-	connect(this, SIGNAL(fullscreenChanged()), this, SLOT(notifyFullscreenChanged()));
-    connect(this, SIGNAL(localeChanged()), this, SLOT(notifyLocaleChanged()));
-    connect(this, SIGNAL(fontChanged()), this, SLOT(notifyFontChanged()));
-    connect(this, SIGNAL(virtualKeyboardChanged()), this, SLOT(notifyVirtualKeyboardChanged()));
-    connect(this, SIGNAL(automaticDownloadsEnabledChanged()), this, SLOT(notifyAutomaticDownloadsEnabledChanged()));
-    connect(this, SIGNAL(filterLevelMinChanged()), this, SLOT(notifyFilterLevelMinChanged()));
-    connect(this, SIGNAL(filterLevelMaxChanged()), this, SLOT(notifyFilterLevelMaxChanged()));
-	connect(this, SIGNAL(sectionVisibleChanged()), this, SLOT(notifySectionVisibleChanged()));
-    connect(this, SIGNAL(demoModeChanged()), this, SLOT(notifyDemoModeChanged()));
-    connect(this, SIGNAL(kioskModeChanged()), this, SLOT(notifyKioskModeChanged()));
-    connect(this, SIGNAL(downloadServerUrlChanged()), this, SLOT(notifyDownloadServerUrlChanged()));
-    connect(this, SIGNAL(exeCountChanged()), this, SLOT(notifyExeCountChanged()));
-    connect(this, SIGNAL(barHiddenChanged()), this, SLOT(notifyBarHiddenChanged()));
+    connect(this, &ApplicationSettings::showLockedActivitiesChanged, this, &ApplicationSettings::notifyShowLockedActivitiesChanged);
+	connect(this, &ApplicationSettings::audioVoicesEnabledChanged, this, &ApplicationSettings::notifyAudioVoicesEnabledChanged);
+	connect(this, &ApplicationSettings::audioEffectsEnabledChanged, this, &ApplicationSettings::notifyAudioEffectsEnabledChanged);
+	connect(this, &ApplicationSettings::fullscreenChanged, this, &ApplicationSettings::notifyFullscreenChanged);
+    connect(this, &ApplicationSettings::localeChanged, this, &ApplicationSettings::notifyLocaleChanged);
+    connect(this, &ApplicationSettings::fontChanged, this, &ApplicationSettings::notifyFontChanged);
+    connect(this, &ApplicationSettings::virtualKeyboardChanged, this, &ApplicationSettings::notifyVirtualKeyboardChanged);
+    connect(this, &ApplicationSettings::automaticDownloadsEnabledChanged, this, &ApplicationSettings::notifyAutomaticDownloadsEnabledChanged);
+    connect(this, &ApplicationSettings::filterLevelMinChanged, this, &ApplicationSettings::notifyFilterLevelMinChanged);
+    connect(this, &ApplicationSettings::filterLevelMaxChanged, this, &ApplicationSettings::notifyFilterLevelMaxChanged);
+	connect(this, &ApplicationSettings::sectionVisibleChanged, this, &ApplicationSettings::notifySectionVisibleChanged);
+    connect(this, &ApplicationSettings::demoModeChanged, this, &ApplicationSettings::notifyDemoModeChanged);
+    connect(this, &ApplicationSettings::kioskModeChanged, this, &ApplicationSettings::notifyKioskModeChanged);
+    connect(this, &ApplicationSettings::downloadServerUrlChanged, this, &ApplicationSettings::notifyDownloadServerUrlChanged);
+    connect(this, &ApplicationSettings::exeCountChanged, this, &ApplicationSettings::notifyExeCountChanged);
+    connect(this, &ApplicationSettings::barHiddenChanged, this, &ApplicationSettings::notifyBarHiddenChanged);
 }
 
 ApplicationSettings::~ApplicationSettings()
@@ -353,6 +357,22 @@ template<class T> void ApplicationSettings::updateValueInConfig(const QString& g
     m_config.sync();
 }
 
+int ApplicationSettings::loadActivityProgress(const QString &activity)
+{
+    int progress = 0;
+    m_config.beginGroup(activity);
+    progress = m_config.value(PROGRESS_KEY, 0).toInt();
+    m_config.endGroup();
+    qDebug() << "loaded progress for activity" << activity << ":" << progress;
+    return progress;
+
+}
+
+void ApplicationSettings::saveActivityProgress(const QString &activity, int progress)
+{
+    updateValueInConfig(activity, PROGRESS_KEY, progress);
+}
+
 QObject *ApplicationSettings::systeminfoProvider(QQmlEngine *engine,
                                                  QJSEngine *scriptEngine)
 {
