@@ -19,8 +19,8 @@
  *   along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 #include <QtDebug>
-#include <QtGui/QGuiApplication>
-#include <QtQuick/QQuickWindow>
+#include <QGuiApplication>
+#include <QQuickWindow>
 #include <QQmlApplicationEngine>
 #include <QStandardPaths>
 #include <QObject>
@@ -238,8 +238,8 @@ int main(int argc, char *argv[])
     }
 
     QQmlApplicationEngine engine(QUrl("qrc:/gcompris/src/core/main.qml"));
-    QObject::connect(&engine, SIGNAL(quit()), DownloadManager::getInstance(),
-                     SLOT(shutdown()));
+    QObject::connect(&engine, &QQmlApplicationEngine::quit, DownloadManager::getInstance(),
+                     &DownloadManager::shutdown);
     // add import path for shipped qml modules:
 #ifdef SAILFISHOS
     engine.addImportPath(QStringLiteral("%1/../share/%2/lib/qml")
